@@ -3,10 +3,9 @@ use strict;
 use warnings;
 use JSON qw//;
 use Sub::Data::Recursive;
-use POSIX qw/strftime/;
 use Getopt::Long qw/GetOptionsFromArray/;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 my $MAX_DEPTH = 10;
 
@@ -26,16 +25,22 @@ my $UNIXTIMESTAMP_KEY = '';
 
 my $GMTIME;
 
+my $INVOKER = 'Sub::Data::Recursive';
+
 sub new {
     my $class = shift;
     my @argv  = @_;
 
     my $opt = $class->_parse_opt(@argv);
 
-    bless {
+    my $self = bless {
         _opt  => $opt,
         _json => JSON->new->utf8->pretty(!$opt->{no_pretty})->canonical(1),
     }, $class;
+
+    $self->_lazyload_modules;
+
+    return $self;
 }
 
 sub opt {
@@ -48,7 +53,7 @@ sub run {
     my ($self) = @_;
 
     while (my $orig_line = <STDIN>) {
-        if ($orig_line !~ m!^[\[\{]!) {
+        if ($orig_line !~ m!^\s*[\[\{]!) {
             print $orig_line;
             next;
         }
@@ -56,6 +61,21 @@ sub run {
     }
 }
 
+sub _lazyload_modules {
+    my ($self) = @_;
+
+    if ($self->opt('xxxx') || $self->opt('timestamp_key')) {
+        require 'POSIX.pm'; ## no critic
+        POSIX->import;
+    }
+
+    if ($self->opt('yaml')) {
+        require 'YAML/Syck.pm'; ## no critic
+        YAML::Syck->import;
+        $YAML::Syck::Headless = $YAML::Syck::SortKeys = 1;
+    }
+}
+
 sub process {
     my ($self, $line) = @_;
 
@@ -67,7 +87,19 @@ sub process {
     }
     else {
         $self->_recursive_process($decoded);
-        return $self->{_json}->encode($decoded)
+        return $self->_output($decoded);
+
+    }
+}
+
+sub _output {
+    my ($self, $decoded) = @_;
+
+    if ($self->opt('yaml')) {
+        return YAML::Syck::Dump($decoded);
+    }
+    else {
+        return $self->{_json}->encode($decoded);
     }
 }
 
@@ -85,17 +117,29 @@ sub _recursive_process {
 sub _recursive_pre_process {
     my ($self, $decoded) = @_;
 
-    Sub::Data::Recursive->invoke(\&_split_lf => $decoded) if $self->opt('x');
+    $INVOKER->invoke(\&_split_lf => $decoded) if $self->opt('x');
 }
 
 sub _recursive_post_process {
     my ($self, $decoded) = @_;
 
-    Sub::Data::Recursive->invoke(\&_split_lf => $decoded) if $self->opt('x');
-    Sub::Data::Recursive->invoke(\&_split_comma => $decoded) if $self->opt('xx');
-    Sub::Data::Recursive->invoke(\&_split_label => $decoded) if $self->opt('xxx');
-    Sub::Data::Recursive->massive_invoke(\&_convert_timestamp => $decoded) if $self->opt('xxxx') || $self->opt('timestamp_key');
-    Sub::Data::Recursive->invoke(\&_trim => $decoded);
+    if ($self->opt('x')) {
+        $INVOKER->invoke(\&_split_lf => $decoded);
+    }
+
+    if ($self->opt('xx')) {
+        $INVOKER->invoke(\&_split_comma => $decoded);
+    }
+
+    if ($self->opt('xxx')) {
+        $INVOKER->invoke(\&_split_label => $decoded);
+    }
+
+    if ($self->opt('xxxx') || $self->opt('timestamp_key')) {
+        $INVOKER->massive_invoke(\&_convert_timestamp => $decoded);
+    }
+
+    $INVOKER->invoke(\&_trim => $decoded);
 }
 
 sub _split_lf {
@@ -186,7 +230,7 @@ sub _ts2date {
             $unix_timestamp = int($unix_timestamp / 1000);
         }
         my @t = $GMTIME ? gmtime($unix_timestamp) : localtime($unix_timestamp);
-        return strftime('%Y-%m-%d %H:%M:%S', @t) . $msec;
+        return POSIX::strftime('%Y-%m-%d %H:%M:%S', @t) . $msec;
     }
 }
 
@@ -224,6 +268,7 @@ sub _parse_opt {
         'xxxx'      => \$opt->{xxxx},
         'timestamp-key=s' => \$opt->{timestamp_key},
         'gmtime'    => \$opt->{gmtime},
+        'yaml|yml'  => \$opt->{yaml},
         'h|help'    => sub {
             $class->_show_usage(1);
         },
@@ -266,14 +311,16 @@ App::jl - Show JSON Log Nicely
 
 =head1 SYNOPSIS
 
+See L<jl> for CLI to view logs.
+
     use App::jl;
+    
+    App::jl->new(@ARGV)->run;
 
 
 =head1 DESCRIPTION
 
-App::jl is recursive JSON decoder. This module can decode JSON in JSON.
-
-See L<jl> for CLI to view logs.
+App::jl is recursive JSON in JSON decoder. It makes JSON log nice.
 
 
 =head1 METHODS
@@ -299,7 +346,7 @@ The parser of the line
 
 =begin html
 
-<a href="http://travis-ci.org/bayashi/App-jl"><img src="https://secure.travis-ci.org/bayashi/App-jl.png?_t=1560527336"/></a> <a href="https://coveralls.io/r/bayashi/App-jl"><img src="https://coveralls.io/repos/bayashi/App-jl/badge.png?_t=1560527336&branch=master"/></a>
+<a href="http://travis-ci.org/bayashi/App-jl"><img src="https://secure.travis-ci.org/bayashi/App-jl.png?_t=1560606718"/></a> <a href="https://coveralls.io/r/bayashi/App-jl"><img src="https://coveralls.io/repos/bayashi/App-jl/badge.png?_t=1560606718&branch=master"/></a>
 
 =end html
 
